<?php

namespace Drupal\data_pipelines\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * A class for the settings form for data pipelines.
 */
class SettingsForm extends ConfigFormBase {

  const CONFIG_NAME = 'data_pipelines.settings';

  /**
   * {@inheritDoc}
   */
  protected function getEditableConfigNames() {
    return [self::CONFIG_NAME];
  }

  /**
   * {@inheritDoc}
   */
  public function getFormId(): string {
    return 'data_pipelines_settings_form';
  }

  /**
   * {@inheritDoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\Core\Config\ImmutableConfig $config */
    $config = $this->config(self::CONFIG_NAME);
    $form = parent::buildForm($form, $form_state);
    $form['index_name_prefix'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Index name prefix'),
      '#description' => $this->t('The prefix for the index name created when storing data for data pipelines.'),
      '#element_validate' => [[static::class, 'validateIndexNamePrefix']],
      '#default_value' => $config->get('index_name_prefix'),
    ];
    return $form;
  }

  /**
   * A method to validate the index name prefix.
   *
   * @param array $element
   *   The element.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public static function validateIndexNamePrefix(array &$element, FormStateInterface $form_state) {
    if (preg_match('/[^\w]+/', $element['#value'])) {
      $form_state->setError($element, t('The index name prefix must be alphanumeric.'));
    }
  }

  /**
   * {@inheritDoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config(self::CONFIG_NAME)
      ->set('index_name_prefix', trim($form_state->getValue('index_name_prefix')))
      ->save();
  }

}
