<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Index;

use Drupal\data_pipelines\Entity\DatasetInterface;

/**
 * Defines a value object for an indexing request.
 */
final class IndexingRequest {

  const TYPE_INDEX = 'index';
  const TYPE_DELETE = 'delete';

  /**
   * UUID to delete.
   *
   * @var string
   */
  protected string $machineName;

  /**
   * Label to delete.
   *
   * @var string
   */
  protected string $label;

  /**
   * Indexing type.
   *
   * @var string
   */
  protected string $type;

  /**
   * Constructs a new IndexDeletionRequest.
   *
   * @param string $machine_name
   *   The machine_name.
   * @param string $label
   *   Label.
   * @param string $type
   *   Indexing type.
   */
  protected function __construct(string $machine_name, string $label, string $type) {
    $this->machineName = $machine_name;
    $this->label = $label;
    $this->type = $type;
  }

  /**
   * Factory method.
   *
   * @param \Drupal\data_pipelines\Entity\DatasetInterface $dataset
   *   Dataset.
   *
   * @return \Drupal\data_pipelines\Index\IndexingRequest
   *   Deletion request.
   */
  public static function deleteDataSet(DatasetInterface $dataset): IndexingRequest {
    return new IndexingRequest($dataset->getMachineName(), $dataset->label(), self::TYPE_DELETE);
  }

  /**
   * Factory method.
   *
   * @param \Drupal\data_pipelines\Entity\DatasetInterface $dataset
   *   Dataset.
   *
   * @return \Drupal\data_pipelines\Index\IndexingRequest
   *   Deletion request.
   */
  public static function forDataSet(DatasetInterface $dataset): IndexingRequest {
    return new IndexingRequest($dataset->getMachineName(), $dataset->label(), self::TYPE_INDEX);
  }

  /**
   * Gets value of machine name.
   *
   * @return string
   *   The machine_name.
   */
  public function getMachineName(): string {
    return $this->machineName;
  }

  /**
   * Gets value of Label.
   *
   * @return string
   *   Value of Label.
   */
  public function getLabel(): string {
    return $this->label;
  }

  /**
   * Checks if is delete request.
   *
   * @return bool
   *   TRUE if is delete request.
   */
  public function isDeleteRequest(): bool {
    return $this->type === self::TYPE_DELETE;
  }

}
