<?php

namespace Drupal\Tests\data_pipelines\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * A class to test the settings form.
 *
 * @group data_pipelines
 *
 * @covers \Drupal\data_pipelines\Form\SettingsForm
 */
class SettingsFormTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'data_pipelines',
    'user',
    'system',
  ];

  /**
   * Tests the settings form.
   */
  public function testSettingsForm(): void {
    $assert = $this->assertSession();

    $url = Url::fromRoute('data_pipelines.settings');
    $this->drupalGet($url);
    $assert->statusCodeEquals(403);
    $this->drupalLogin($this->createUser([
      'administer data_pipelines',
    ]));
    $this->drupalGet($url);
    $assert->statusCodeEquals(200);

    $this->submitForm([
      'index_name_prefix' => 'blah%',
    ], 'Save configuration');
    $assert->pageTextContains('The index name prefix must be alphanumeric.');

    $this->submitForm([
      'index_name_prefix' => 'foo',
    ], 'Save configuration');
    $this->assertEquals('foo', \Drupal::config('data_pipelines.settings')->get('index_name_prefix'));
  }

}
